function [rhs,gamma] = function_h(pp,A,C,delta)
% [rhs,gamma] = function_h(pp,a,c,delta)
%
% Function h as defined in (23).
%
% pp can be a vector.
%
% --
% Supplementary material to
%
% S. Trimpe, R. D'Andrea, "Event-Based State Estimation with Variance-Based 
% Triggering", Proc. of the 51st IEEE Conference on Decision and Control, 
% 2012.
%
% Copyright:
% Sebastian Trimpe
% ETH Zurich
% Institute for Dynamic Systems and Control (IDSC)
% strimpe(at)ethz.ch
% March 2012
%

% Revision history
% [March 12, Seb]   first version


% \bar{p}: solution to the DARE
pbar = dare(A,C,1,1);               % Q and R assumed 1

% Transmit decision
gamma = (pp >= pbar+delta); 

% Evaluate h(p)
rhs = A^2*pp + 1 - gamma.*A^2*C^2.*pp.^2./(C^2*pp+1);

